@@ -171,7 +171,7 @@ forecast.StructTS <- function(
   level <- getConfLevel(level, fan)
   nint <- length(level)
   upper <- lower <- matrix(NA, ncol = nint, nrow = length(pred$pred))
-  for (i in 1:nint) {
+  for (i in seq_len(nint)) {
     qq <- qnorm(0.5 * (1 + level[i] / 100))
     lower[, i] <- pred$pred - qq * pred$se
     upper[, i] <- pred$pred + qq * pred$se
@@ -279,7 +279,7 @@ forecast.HoltWinters <- function(
   pmean <- pred[, 1]
   upper <- lower <- matrix(NA, ncol = nint, nrow = length(pred[, 1]))
   se <- (pred[, 2] - pred[, 3]) / (2 * qnorm(0.5 * (1 + level[1] / 100)))
-  for (i in 1:nint) {
+  for (i in seq_len(nint)) {
     qq <- qnorm(0.5 * (1 + level[i] / 100))
     lower[, i] <- pmean - qq * se
     upper[, i] <- pmean + qq * se
