@@ -16,15 +16,13 @@
 // to this object with name "ets.xptr"
 // to the environment submitted as p_rho
 //
-RcppExport SEXP etsTargetFunctionInit(SEXP p_y, SEXP p_nstate, SEXP p_errortype, SEXP p_trendtype,
+// [[Rcpp::export]]
+SEXP etsTargetFunctionInit(SEXP p_y, SEXP p_nstate, SEXP p_errortype, SEXP p_trendtype,
 		SEXP p_seasontype, SEXP p_damped, SEXP p_lower, SEXP p_upper,
 		SEXP p_opt_crit, SEXP p_nmse, SEXP p_bounds, SEXP p_m,
 		SEXP p_optAlpha, SEXP p_optBeta, SEXP p_optGamma, SEXP p_optPhi,
 		SEXP p_givenAlpha, SEXP p_givenBeta, SEXP p_givenGamma, SEXP p_givenPhi,
 		SEXP p_alpha, SEXP p_beta, SEXP p_gamma, SEXP p_phi, SEXP p_rho) {
-
-	BEGIN_RCPP;
-
 	EtsTargetFunction* sp = new EtsTargetFunction();
 
 	std::vector<double> y = Rcpp::as< std::vector<double> >(p_y);
@@ -70,65 +68,8 @@ RcppExport SEXP etsTargetFunctionInit(SEXP p_y, SEXP p_nstate, SEXP p_errortype,
 	e["ets.xptr"] = Rcpp::XPtr<EtsTargetFunction>( sp, true );
 
 	return Rcpp::wrap(e);
-
-	END_RCPP;
 }
 
-// RcppExport double targetFunctionRmalschains(SEXP p_par, SEXP p_env)
-// {
-// 	Rcpp::NumericVector par(p_par);
-
-// 	Rcpp::Environment e(p_env);
-// 	Rcpp::XPtr<EtsTargetFunction> sp(e.get("ets.xptr"));
-
-// 	sp->eval(par.begin(), par.size());
-
-// 	//return Rcpp::wrap(sp->getObjVal());
-// 	return sp->getObjVal();
-
-// }
-
-// RcppExport SEXP etsGetTargetFunctionRmalschainsPtr() {
-
-// 	typedef double (*funcPtr)(SEXP, SEXP);
-// 	return (Rcpp::XPtr<funcPtr>(new funcPtr(&targetFunctionRmalschains)));
-// }
-
-/*
-RcppExport SEXP targetFunctionRdonlp2(SEXP p_var, SEXP p_env)
-{
-
-	Rcpp::Environment e(p_env);
-	Rcpp::XPtr<EtsTargetFunction> sp(e.get("ets.xptr"));
-
-	Rcpp::NumericVector var(p_var);
-
-	int mode = var[0];
-	int fun_id = var[1];
-
-	sp->eval(var.begin()+2, var.size()-2);
-
-	if(mode == 0) {
-		if(fun_id == 0) {
-			return Rcpp::wrap(sp->getObjVal());
-		} else {
-			return Rcpp::wrap(0);
-			//return Rcpp::wrap(sp->restrictions[fun_id-1]);
-		}
-	} else if(mode==1) {
-		//		error("Gradients are not implemented, exiting.");
-	};
-
-	return R_NilValue;
-}
-
-RcppExport SEXP etsGetTargetFunctionRdonlp2Ptr() {
-
-	typedef SEXP (*funcPtr)(SEXP, SEXP);
-	return (Rcpp::XPtr<funcPtr>(new funcPtr(&targetFunctionRdonlp2)));
-}
-*/
-
 double targetFunctionEtsNelderMead(int n, double *par, void *ex)
 {
 	EtsTargetFunction* sp = (EtsTargetFunction*) ex;
@@ -138,7 +79,8 @@ double targetFunctionEtsNelderMead(int n, double *par, void *ex)
 
 }
 
-RcppExport SEXP etsNelderMead(SEXP p_var, SEXP p_env, SEXP p_abstol,
+// [[Rcpp::export]]
+SEXP etsNelderMead(SEXP p_var, SEXP p_env, SEXP p_abstol,
 		SEXP p_intol, SEXP p_alpha, SEXP p_beta, SEXP p_gamma,
 		SEXP p_trace, SEXP p_maxit)
 {
